@@ -7,10 +7,12 @@ import (
 	"strings"
 
 	"github.com/charmbracelet/bubbles/list"
+	progress_ "github.com/charmbracelet/bubbles/progress"
 	"github.com/charmbracelet/bubbles/spinner"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/lipgloss"
 	cache_ "github.com/jandedobbeleer/oh-my-posh/src/cache"
+	"github.com/jandedobbeleer/oh-my-posh/src/progress"
 	"github.com/jandedobbeleer/oh-my-posh/src/terminal"
 )
 
@@ -22,12 +24,11 @@ var (
 const listHeight = 14
 
 var (
-	titleStyle        = lipgloss.NewStyle().MarginLeft(2)
-	itemStyle         = lipgloss.NewStyle().PaddingLeft(4)
+	itemStyle         = lipgloss.NewStyle().PaddingLeft(3)
 	selectedItemStyle = lipgloss.NewStyle().PaddingLeft(2).Foreground(lipgloss.Color("170"))
-	paginationStyle   = list.DefaultStyles().PaginationStyle.PaddingLeft(4)
-	helpStyle         = lipgloss.NewStyle().PaddingLeft(4).PaddingBottom(1)
-	textStyle         = lipgloss.NewStyle().Margin(1, 0, 2, 4)
+	paginationStyle   = list.DefaultStyles().PaginationStyle.PaddingLeft(3)
+	helpStyle         = lipgloss.NewStyle().PaddingLeft(3).PaddingBottom(1)
+	textStyle         = lipgloss.NewStyle().Margin(1, 0, 2, 2)
 )
 
 type loadMsg []*Asset
@@ -54,7 +55,7 @@ func (d itemDelegate) Render(w io.Writer, m list.Model, index int, listItem list
 	fn := itemStyle.Render
 	if index == m.Index() {
 		fn = func(s ...string) string {
-			return selectedItemStyle.Render("> " + strings.Join(s, " "))
+			return selectedItemStyle.Render("•" + strings.Join(s, " "))
 		}
 	}
 
@@ -72,11 +73,12 @@ const (
 )
 
 type main struct {
-	err  error
-	list *list.Model
+	err      error
+	list     *list.Model
+	spinner  *spinner.Model
+	progress *progress.Model
 	Asset
 	families []string
-	spinner  spinner.Model
 	state    state
 	system   bool
 }
@@ -93,7 +95,6 @@ func (m *main) buildFontList(nerdFonts []*Asset) {
 	l.Title = "Select font"
 	l.SetShowStatusBar(false)
 	l.SetFilteringEnabled(false)
-	l.Styles.Title = titleStyle
 	l.Styles.PaginationStyle = paginationStyle
 	l.Styles.HelpStyle = helpStyle
 
@@ -174,6 +175,11 @@ func (m *main) Init() tea.Cmd {
 		return nil
 	}
 
+	m.progress = progress.NewModel()
+
+	s := spinner.New()
+	m.spinner = &s
+
 	if len(m.URL) != 0 && !isLocalZipFile() {
 		m.state = downloadFont
 
@@ -199,10 +205,8 @@ func (m *main) Init() tea.Cmd {
 		go getFontsList()
 	}()
 
-	s := spinner.New()
-	s.Spinner = spinner.Dot
-	s.Style = lipgloss.NewStyle().Foreground(lipgloss.Color("170"))
-	m.spinner = s
+	m.spinner.Spinner = spinner.Dot
+	m.spinner.Style = lipgloss.NewStyle().Foreground(lipgloss.Color("170"))
 	m.state = getFonts
 
 	if isLocalZipFile() {
@@ -276,6 +280,12 @@ func (m *main) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			return m, nil
 		}
 
+	case progress.Message:
+		return m, m.progress.SetPercent(float64(msg))
+
+	case progress_.FrameMsg:
+		return m, m.progress.Update(msg)
+
 	case zipMsg:
 		m.state = installFont
 		defer func() {
@@ -294,8 +304,8 @@ func (m *main) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		return m, tea.Quit
 
 	default:
-		var cmd tea.Cmd
-		m.spinner, cmd = m.spinner.Update(msg)
+		s, cmd := m.spinner.Update(msg)
+		m.spinner = &s
 		return m, cmd
 	}
 
@@ -319,7 +329,7 @@ func (m *main) View() string {
 	case selectFont:
 		return fmt.Sprintf("\n%s%s", m.list.View(), terminal.StopProgress())
 	case downloadFont:
-		return textStyle.Render(fmt.Sprintf("%s Downloading %s%s", m.spinner.View(), m.Name, terminal.StartProgress()))
+		return textStyle.Render(fmt.Sprintf("Downloading %s...\n%s", m.Name, m.progress.View()))
 	case unzipFont:
 		return textStyle.Render(fmt.Sprintf("%s Extracting %s", m.spinner.View(), m.Name))
 	case installFont:
